@@ -44,6 +44,9 @@ namespace TheSeer\Autoload\Tests {
 
     class FactoryTest extends \PHPUnit\Framework\TestCase {
 
+        private $factory;
+        private $config;
+
         public function setUp(): void {
             $this->factory = new Factory();
             $this->config = new Config(array());
